@@ -1,7 +1,7 @@
 # $Id: Term.pm 2010-12-22 erick.antezana $
 #
 # Module  : Term.pm
-# Purpose : Term in the Ontology.
+# Purpose : Term of an Ontology.
 # License : Copyright (c) 2006-2011 by Erick Antezana. All rights reserved.
 #           This program is free software; you can redistribute it and/or
 #           modify it under the same terms as Perl itself.
@@ -9,10 +9,9 @@
 #
 package OBO::Core::Term;
 
-use OBO::Core::Def;
+use OBO::Util::InstanceSet;
 use OBO::Core::Synonym;
 use OBO::Util::SynonymSet;
-use OBO::Util::Set;
 use strict;
 use warnings;
 
@@ -31,6 +30,7 @@ sub new {
 	$self->{SUBSET_SET}         = OBO::Util::Set->new();        # set of scalars (0..N)
 	$self->{SYNONYM_SET}        = OBO::Util::SynonymSet->new(); # set of synonyms (0..N)
 	$self->{XREF_SET}           = OBO::Util::DbxrefSet->new();  # set of dbxref's (0..N)
+	$self->{CLASS_OF}           = OBO::Util::InstanceSet->new();# set of instances (0..N)
 	$self->{INTERSECTION_OF}    = OBO::Util::Set->new();        # (0..N)
 	$self->{UNION_OF}           = OBO::Util::Set->new();        # (0..N)
 	$self->{DISJOINT_FROM}      = OBO::Util::Set->new();        # (0..N)
@@ -71,7 +71,7 @@ sub id {
 =cut
 
 sub idspace {
-	my $self = shift;
+	my ($self) = @_;
 	$self->{ID} =~ /([A-Za-z_]+):/ if ($self->{ID});
 	return $1 || 'NN';
 }
@@ -86,7 +86,7 @@ sub idspace {
 =cut
 
 sub subnamespace {
-	my $self = shift;
+	my ($self) = @_;
 	$self->{ID} =~ /:([A-Z][a-z]?)/ if ($self->{ID});
 	return $1 || 'X';
 }
@@ -101,7 +101,7 @@ sub subnamespace {
 =cut
 
 sub code {
-	my $self = shift;
+	my ($self) = @_;
 	$self->{ID} =~ /:[A-Z]?[a-z]?(.*)/ if ($self->{ID});	
 	return $1 || '0000000';
 }
@@ -176,6 +176,7 @@ sub def {
   Returns  - the definition (string) of this term
   Args     - the definition (string) of this term plus the dbxref list (string) describing the source of this definition
   Function - gets/sets the definition of this term
+  Remark   - make sure that colons (,) are scaped (\,) when necessary
   
 =cut
 
@@ -278,7 +279,7 @@ sub namespace {
 
 sub comment {
 	my ($self, $comment) = @_;
-	if ($comment) { $self->{COMMENT} = $comment }
+	if (defined $comment) { $self->{COMMENT} = $comment }
 	return $self->{COMMENT};
 }
 
@@ -404,6 +405,7 @@ sub xref_set {
   Returns  - the dbxref set with the analogous xref(s) of this term; [] if the set is empty
   Args     - the dbxref set with the analogous xref(s) of this term
   Function - gets/sets the dbxref set with the analogous xref(s) of this term
+  Remark   - make sure that colons (,) are scaped (\,) when necessary
   
 =cut
 
@@ -415,7 +417,6 @@ sub xref_set_as_string {
 		$xref_as_string =~ s/\\,/;;;;/g;  # trick to keep the comma's
 		$xref_as_string =~ s/\\"/;;;;;/g; # trick to keep the double quote's
 		my $xref_set = $self->{XREF_SET};
-		
 		my @lineas = $xref_as_string =~ /\"([^\"]*)\"/g; # get the double-quoted pieces
 		foreach my $l (@lineas) {
 			my $cp = $l;
@@ -457,6 +458,39 @@ sub xref_set_as_string {
 	my @result = $self->xref_set()->get_set();
 }
 
+=head2 class_of
+
+  Usage    - $term->class_of() or $term->class_of($instance1, $instance2, $instance3, ...)
+  Returns  - an array with the instance(s) of this term
+  Args     - the instance(s) (OBO::Core::Instance) of this term
+  Function - gets/sets the instance(s) of this term
+  
+=cut
+
+sub class_of {
+	my ($self, @co) = @_;
+	
+	foreach my $i (@co) {
+		$self->{CLASS_OF}->add($i);
+		$i->instance_of($self); # make the instance aware of its class (term)
+	}
+	return $self->{CLASS_OF};
+}
+
+=head2 is_class_of
+
+  Usage    - $term->is_class_of($instance)
+  Returns  - either 1 (true) or 0 (false)
+  Args     - an instance (OBO::Core::Instance) of which this object might be class of
+  Function - tells whether this object is a class of $instance
+  
+=cut
+
+sub is_class_of {
+	my ($self, $instance) = @_;
+	return (defined $instance && $self->{CLASS_OF}->contains($instance));
+}
+
 =head2 intersection_of
         
   Usage    - $term->intersection_of() or $term->intersection_of($t1, $t2, $r1, ...)
@@ -882,6 +916,8 @@ foreach my $ref_n2 (@refs_n2) {
 
 A Term in the ontology. c.f. OBO flat file specification.
 
+Recommended: http://ontology.buffalo.edu/bfo/Terminology_for_Ontologies.pdf
+
 =head1 AUTHOR
 
 Erick Antezana, E<lt>erick.antezana -@- gmail.comE<gt>
