@@ -2,7 +2,7 @@
 #
 # Module  : OBO_ID_Set.pm
 # Purpose : A set of OBO id's.
-# License : Copyright (c) 2006, 2007, 2008, 2009, 2010 Erick Antezana. All rights reserved.
+# License : Copyright (c) 2006-2011 by Erick Antezana. All rights reserved.
 #           This program is free software; you can redistribute it and/or
 #           modify it under the same terms as Perl itself.
 # Contact : Erick Antezana <erick.antezana -@- gmail.com>
@@ -67,7 +67,7 @@ sub add_all_as_string () {
 sub get_new_id {
 	my ($self, $local_idspace) = @_;
 	my $new_obo_id = OBO::XO::OBO_ID->new();
-	die "The local idspace is invalid: ", $local_idspace if ($local_idspace !~ /\w+/);
+	die 'The local idspace is invalid: ', $local_idspace if ($local_idspace !~ /\w+/);
 	$new_obo_id->idspace($local_idspace);
 	# get the last 'localID'
 	if ($self->is_empty()){
@@ -116,7 +116,7 @@ Erick Antezana, E<lt>erick.antezana -@- gmail.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2006, 2007, 2008, 2009, 2010 by Erick Antezana
+Copyright (C) 2006-2011 by Erick Antezana
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.7 or,
